.. _`Procedural Phasor Noise`: https://hal.science/hal-02118508/file/ProceduralPhasorNoise.pdf

|GPL| |Update| |PyPI|  |HAL|

.. |GPL| image:: https://img.shields.io/github/license/etachouzin/phasor_noise?color=blue
   :alt: GPL

.. |Update| image:: https://img.shields.io/github/last-commit/etachouzin/phasor_noise
   :alt: GitHub last commit

.. |PyPI| image:: https://img.shields.io/static/v1?logo=pypi&message=PyPI&label=&color=yellow
   :target: https://pypi.org/project/Phasor-Noise/
   :alt: PyPI

.. |HAL| image:: https://hal.science/assets/img/hal-logo-header.png
   :target: https://hal.science/
   :alt: HAL
   :width: 20pt

About The Project
------------------
We created a Phasor noise generator with a graphical interface to visualize how the different parameters affect the noise created.
We created it with this study `Procedural Phasor Noise`_

Installation
-------------

1. Install from PyPI

.. code:: console

   pip install Phasor-Noise

Usage
---------
You can now use Phasor-Noise and launch the default window setup.

.. code:: python

   import phasor_noise
   phasor_noise.default_window()



License
-----------

Distributed under the GNU License.

Authors
-----------
* Alexis Le Meur
* Etienne Tachouzin
* Paul Martin
* Guillaume Hisleur
* Paul Bedrossian
